@@ -5,12 +5,12 @@ use warnings;
 use base qw/DBIx::Class::Schema::Loader::Base/;
 use mro 'c3';
 use Try::Tiny;
-use List::MoreUtils 'any';
+use List::Util 'any';
 use Carp::Clan qw/^DBIx::Class/;
 use namespace::clean;
 use DBIx::Class::Schema::Loader::Table ();
 
-our $VERSION = '0.07036_04';
+our $VERSION = '0.07048_01';
 
 __PACKAGE__->mk_group_accessors('simple', qw/
     _disable_pk_detection
@@ -74,8 +74,8 @@ sub _build_quote_char {
     my $self = shift;
 
     my $quote_char = $self->dbh->get_info(29)
-           || $self->schema->storage->sql_maker->quote_char
-           || q{"};
+        || $self->schema->storage->sql_maker->quote_char
+        || q{"};
 
     # For our usage as regex matches, concatenating multiple quote_char
     # values works fine (e.g. s/[\Q<>\E]// if quote_char was [ '<', '>' ])
@@ -89,8 +89,8 @@ sub _build_quote_char {
 sub _build_name_sep {
     my $self = shift;
     return $self->dbh->get_info(41)
-           || $self->schema->storage->sql_maker->name_sep
-           || '.';
+        || $self->schema->storage->sql_maker->name_sep
+        || '.';
 }
 
 # Override this in vendor modules to do things at the end of ->new()
@@ -108,11 +108,9 @@ sub _system_tables {
 }
 
 sub _dbh_tables {
-    my ($self, $schema) = (shift, shift);
+    my $self = shift;
 
-    my ($table_pattern, $table_type_pattern) = @_ ? @_ : ('%', '%');
-
-    return $self->dbh->tables(undef, $schema, $table_pattern, $table_type_pattern);
+    return $self->dbh->tables(undef, @_);
 }
 
 # default to be overridden in subclasses if necessary
@@ -120,7 +118,7 @@ sub _supports_db_schema { 1 }
 
 # Returns an array of table objects
 sub _tables_list {
-    my ($self, $opts) = (shift, shift);
+    my ($self) = @_;
 
     my @tables;
 
@@ -130,7 +128,7 @@ sub _tables_list {
     my $nns = qr/[^\Q$self->{name_sep}\E]/;
 
     foreach my $schema (@{ $self->db_schema || [undef] }) {
-        my @raw_table_names = $self->_dbh_tables($schema, @_);
+        my @raw_table_names = $self->_dbh_tables($schema);
 
         TABLE: foreach my $raw_table_name (@raw_table_names) {
             my $quoted = $raw_table_name =~ /^$qt/;
@@ -151,7 +149,7 @@ sub _tables_list {
                     if (ref $system_schema) {
                         $matches = 1
                             if $schema_name =~ $system_schema
-                                 && $schema !~ $system_schema;
+                                && $schema  !~ $system_schema;
                     }
                     else {
                         $matches = 1
@@ -191,7 +189,7 @@ sub _tables_list {
         }
     }
 
-    return $self->_filter_tables(\@tables, $opts);
+    return $self->_filter_tables(\@tables);
 }
 
 sub _recurse_constraint {
@@ -230,14 +228,13 @@ sub _check_constraint {
 
 # apply constraint/exclude and ignore bad tables and views
 sub _filter_tables {
-    my ($self, $tables, $opts) = @_;
+    my ($self, $tables) = @_;
 
     my @tables = @$tables;
     my @filtered_tables;
 
-    $opts ||= {};
-    @tables = _check_constraint(1, $opts->{constraint}, @tables);
-    @tables = _check_constraint(0, $opts->{exclude}, @tables);
+    @tables = _check_constraint(1, $self->constraint, @tables);
+    @tables = _check_constraint(0, $self->exclude, @tables);
 
     TABLE: for my $table (@tables) {
         try {
@@ -270,15 +267,13 @@ sub load {
     local $self->dbh->{PrintError} = 0;
 
     $self->next::method(@_);
-
-    $self->schema->storage->disconnect unless $self->dynamic;
 }
 
 sub _sth_for {
     my ($self, $table, $fields, $where) = @_;
 
     my $sth = $self->dbh->prepare($self->schema->storage->sql_maker
-        ->select(\$table->sql_name, $fields, $where));
+        ->select(\$table->sql_name, $fields || \'*', $where));
 
     return $sth;
 }
@@ -340,17 +335,18 @@ sub _table_uniq_info {
         next if $row->{TYPE} eq 'table'
             || defined $row->{FILTER_CONDITION}
             || !$row->{INDEX_NAME}
-            || !defined $row->{ORDINAL_POSITION}
-            || !$row->{COLUMN_NAME};
+            || !defined $row->{ORDINAL_POSITION};
 
-        $indices{$row->{INDEX_NAME}}[$row->{ORDINAL_POSITION}] = $self->_lc($row->{COLUMN_NAME});
+        $indices{$row->{INDEX_NAME}}[$row->{ORDINAL_POSITION}] = $self->_lc($row->{COLUMN_NAME} || '');
     }
     $sth->finish;
 
     my @retval;
-    foreach my $index_name (keys %indices) {
-        my $index = $indices{$index_name};
-        push(@retval, [ $index_name => [ @$index[1..$#$index] ] ]);
+    foreach my $index_name (sort keys %indices) {
+        my (undef, @cols) = @{$indices{$index_name}};
+        # skip indexes with missing column names (e.g. expression indexes)
+        next unless @cols == grep $_, @cols;
+        push(@retval, [ $index_name => \@cols ]);
     }
 
     return \@retval;
@@ -692,9 +688,9 @@ sub _table_is_view {
 
 L<DBIx::Class::Schema::Loader>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+See L<DBIx::Class::Schema::Loader/AUTHORS>.
 
 =head1 LICENSE
 
