@@ -8,12 +8,12 @@ use base qw/
 /;
 use mro 'c3';
 
-use List::MoreUtils 'any';
+use List::Util 'any';
 use namespace::clean;
 
 use DBIx::Class::Schema::Loader::Table ();
 
-our $VERSION = '0.07036_04';
+our $VERSION = '0.07048_01';
 
 =head1 NAME
 
@@ -75,7 +75,7 @@ EOF
         my ($col, $constname, $seq) = @$row;
         push(@{$keydata{$constname}}, [ $seq, $self->_lc($col) ]);
     }
-    foreach my $keyname (keys %keydata) {
+    foreach my $keyname (sort keys %keydata) {
         my @ordered_cols = map { $_->[1] } sort { $a->[0] <=> $b->[0] }
             @{$keydata{$keyname}};
         push(@uniqs, [ $keyname => \@ordered_cols ]);
@@ -104,6 +104,8 @@ JOIN syscat.references sr
         AND tc.tabname = sr.tabname
 JOIN syscat.keycoluse rkcu
     ON sr.refkeyname = rkcu.constname
+        AND sr.reftabschema = rkcu.tabschema
+        AND sr.reftabname = rkcu.tabname
         AND kcu.colseq = rkcu.colseq
 WHERE tc.tabschema = ?
     AND tc.tabname = ?
@@ -152,11 +154,22 @@ EOF
 }
 
 
-# DBD::DB2 doesn't follow the DBI API for ->tables
+# DBD::DB2 doesn't follow the DBI API for ->tables (pre 1.85), but since its
+# backwards compatible we don't change it.
+# DBD::DB2 1.85 and beyond default TABLE_NAME to '', previously defaulted to
+# '%'. so we supply it.
 sub _dbh_tables {
     my ($self, $schema) = @_;
 
-    return $self->dbh->tables($schema ? { TABLE_SCHEM => $schema } : undef);
+    return $self->dbh->tables($schema ? { TABLE_SCHEM => $schema, TABLE_NAME => '%' } : undef);
+}
+
+sub _dbh_table_info {
+    my $self = shift;
+
+    local $^W = 0; # shut up undef warning from DBD::DB2
+
+    $self->next::method(@_);
 }
 
 sub _columns_info_for {
@@ -246,9 +259,9 @@ EOF
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+See L<DBIx::Class::Schema::Loader/AUTHORS>.
 
 =head1 LICENSE
 
