@@ -5,7 +5,7 @@ use warnings;
 use base 'DBIx::Class::Schema::Loader::DBI';
 use mro 'c3';
 
-our $VERSION = '0.07036_04';
+our $VERSION = '0.07048_01';
 
 =head1 NAME
 
@@ -22,28 +22,22 @@ See L<DBIx::Class::Schema::Loader::Base> for usage information.
 =cut
 
 sub _rebless {
-  my $self = shift;
+    my $self = shift;
 
-  return if ref $self ne __PACKAGE__;
+    return if ref $self ne __PACKAGE__;
 
-# stolen from DBIC ODBC storage
-  my $dbh  = $self->schema->storage->dbh;
-  my $dbtype = eval { $dbh->get_info(17) };
-  unless ( $@ ) {
-    # Translate the backend name into a perl identifier
-    $dbtype =~ s/\W/_/gi;
-    my $class = "DBIx::Class::Schema::Loader::DBI::ODBC::${dbtype}";
-    if ($self->load_optional_class($class) && !$self->isa($class)) {
-        bless $self, $class;
-        $self->_rebless;
+    # stolen from DBIC ODBC storage
+    my $dbh  = $self->schema->storage->dbh;
+    my $dbtype = eval { $dbh->get_info(17) };
+    unless ( $@ ) {
+        # Translate the backend name into a perl identifier
+        $dbtype =~ s/\W/_/gi;
+        my $class = "DBIx::Class::Schema::Loader::DBI::ODBC::${dbtype}";
+        if ($self->load_optional_class($class) && !$self->isa($class)) {
+            bless $self, $class;
+            $self->_rebless;
+        }
     }
-  }
-}
-
-sub _tables_list {
-    my ($self, $opts) = @_;
-
-    return $self->next::method($opts, undef, undef);
 }
 
 =head1 SEE ALSO
@@ -54,9 +48,9 @@ L<DBIx::Class::Schema::Loader::DBI::ODBC::Firebird>,
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+See L<DBIx::Class::Schema::Loader/AUTHORS>.
 
 =head1 LICENSE
 
