@@ -5,7 +5,7 @@ use warnings;
 use base 'DBIx::Class::Schema::Loader::DBI::Component::QuotedDefault';
 use mro 'c3';
 
-our $VERSION = '0.07036_04';
+our $VERSION = '0.07048_01';
 
 =head1 NAME
 
@@ -125,15 +125,15 @@ sub _table_uniq_info {
           pg_catalog.pg_index x
           JOIN pg_catalog.pg_class c ON c.oid = x.indrelid
           JOIN pg_catalog.pg_class i ON i.oid = x.indexrelid
-          JOIN pg_catalog.pg_constraint con ON con.conname = i.relname
-          LEFT JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
+          JOIN pg_catalog.pg_namespace n ON n.oid = c.relnamespace
         WHERE
           x.indisunique = 't' AND
+          x.indpred     IS NULL AND
           c.relkind     = 'r' AND
           i.relkind     = 'i' AND
-          con.contype   = 'u' AND
           n.nspname     = ? AND
-          c.relname     = ?}
+          c.relname     = ?
+        ORDER BY i.relname}
     );
 
     $uniq_sth->execute($table->schema, $table->name);
@@ -149,10 +149,8 @@ sub _table_uniq_info {
             push(@col_names, $self->_lc($name_aref->[0])) if $name_aref;
         }
 
-        if(!@col_names) {
-            warn "Failed to parse UNIQUE constraint $indexname on $table";
-        }
-        else {
+        # skip indexes with missing column names (e.g. expression indexes)
+        if(@col_names == @col_nums) {
             push(@uniqs, [ $indexname => \@col_names ]);
         }
     }
@@ -186,13 +184,11 @@ sub _column_comment {
 
     return $column_comment if $column_comment;
 
-    my ($table_oid) = $self->dbh->selectrow_array(<<'EOF', {}, $table->name, $table->schema);
-SELECT oid
+    return $self->dbh->selectrow_array(<<'EOF', {}, $column_number, $table->name, $table->schema);
+SELECT pg_catalog.col_description(oid, ?)
 FROM pg_catalog.pg_class
 WHERE relname=? AND relnamespace=(SELECT oid FROM pg_catalog.pg_namespace WHERE nspname=?)
 EOF
-
-    return $self->dbh->selectrow_array('SELECT pg_catalog.col_description(?,?)', {}, $table_oid, $column_number);
 }
 
 # Make sure data_type's that don't need it don't have a 'size' column_info, and
@@ -229,7 +225,7 @@ WHERE table_name = ? and column_name = ?
 EOF
 
             if ($data_type =~ /^time\b/i) {
-                if ((not $precision) || $precision !~ /^\d/) {
+                if ((not defined $precision) || $precision !~ /^\d/) {
                     delete $info->{size};
                 }
                 else {
@@ -247,7 +243,7 @@ EOF
                     }
                 }
             }
-            elsif ((not $precision) || $precision !~ /^\d/ || $precision == 6) {
+            elsif ((not defined $precision) || $precision !~ /^\d/ || $precision == 6) {
                 delete $info->{size};
             }
             else {
@@ -290,25 +286,21 @@ EOF
                 ->selectrow_array(<<EOF, {}, $data_type);
 SELECT typtype
 FROM pg_catalog.pg_type
-WHERE typname = ?
+WHERE oid = ?::regtype
 EOF
             if ($typetype && $typetype eq 'e') {
-                # The following will extract a list of allowed values for the
-                # enum.
+                # The following will extract a list of allowed values for the enum.
                 my $order_column = $self->dbh->{pg_server_version} >= 90100 ? 'enumsortorder' : 'oid';
-                my $typevalues = $self->dbh
-                    ->selectall_arrayref(<<EOF, {}, $info->{data_type});
+                $info->{extra}{list} = $self->dbh
+                    ->selectcol_arrayref(<<EOF, {}, $data_type);
 SELECT e.enumlabel
 FROM pg_catalog.pg_enum e
-JOIN pg_catalog.pg_type t ON t.oid = e.enumtypid
-WHERE t.typname = ?
+WHERE e.enumtypid = ?::regtype
 ORDER BY e.$order_column
 EOF
 
-                $info->{extra}{list} = [ map { $_->[0] } @$typevalues ];
-
                 # Store its original name in extra for SQLT to pick up.
-                $info->{extra}{custom_type_name} = $info->{data_type};
+                $info->{extra}{custom_type_name} = $data_type;
 
                 $info->{data_type} = 'enum';
 
@@ -316,24 +308,28 @@ EOF
             }
         }
 
-# process SERIAL columns
-        if (ref($info->{default_value}) eq 'SCALAR'
-                && ${ $info->{default_value} } =~ /\bnextval\('([^:]+)'/i) {
-            $info->{is_auto_increment} = 1;
-            $info->{sequence}          = $1;
-            delete $info->{default_value};
+        if (ref($info->{default_value}) eq 'SCALAR') {
+            # process SERIAL columns
+            if (${ $info->{default_value} } =~ /\bnextval\('([^:]+)'/i) {
+                $info->{is_auto_increment} = 1;
+                $info->{sequence}          = $1;
+                delete $info->{default_value};
+            }
+            # alias now() to current_timestamp for deploying to other DBs
+            elsif (lc ${ $info->{default_value} } eq 'now()') {
+                # do not use a ref to a constant, that breaks Data::Dump output
+                ${$info->{default_value}} = 'current_timestamp';
+
+                my $now = 'now()';
+                $info->{original}{default_value} = \$now;
+            }
+            elsif (${ $info->{default_value} } =~ /\bCURRENT_TIMESTAMP\b/) {
+                # PostgreSQL v10 upcases current_timestamp in default values
+                ${ $info->{default_value} } =~ s/\b(CURRENT_TIMESTAMP)\b/lc $1/ge;
+            }
         }
 
-# alias now() to current_timestamp for deploying to other DBs
-        if ((eval { lc ${ $info->{default_value} } }||'') eq 'now()') {
-            # do not use a ref to a constant, that breaks Data::Dump output
-            ${$info->{default_value}} = 'current_timestamp';
-
-            my $now = 'now()';
-            $info->{original}{default_value} = \$now;
-        }
-
-# detect 0/1 for booleans and rewrite
+        # detect 0/1 for booleans and rewrite
         if ($data_type =~ /^bool/i && exists $info->{default_value}) {
             if ($info->{default_value} eq '0') {
                 my $false = 'false';
@@ -349,14 +345,30 @@ EOF
     return $result;
 }
 
+sub _view_definition {
+    my ($self, $view) = @_;
+
+    my $def =  $self->schema->storage->dbh->selectrow_array(<<'EOF', {}, $view->schema, $view->name);
+SELECT pg_catalog.pg_get_viewdef(oid)
+FROM pg_catalog.pg_class
+WHERE relnamespace = (SELECT OID FROM pg_catalog.pg_namespace WHERE nspname = ?)
+AND relname = ?
+EOF
+    # The definition is returned as a complete statement including the
+    # trailing semicolon, but that's not allowed in CREATE VIEW, so
+    # strip it out
+    $def =~ s/\s*;\s*\z//;
+    return $def;
+}
+
 =head1 SEE ALSO
 
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+See L<DBIx::Class::Schema::Loader/AUTHORS>.
 
 =head1 LICENSE
 
