@@ -6,7 +6,7 @@ use base 'DBIx::Class::Schema::Loader::DBI::Component::QuotedDefault';
 use mro 'c3';
 use DBIx::Class::Schema::Loader::Table ();
 
-our $VERSION = '0.07036_04';
+our $VERSION = '0.07048_01';
 
 =head1 NAME
 
@@ -63,7 +63,7 @@ sub _columns_info_for {
     local $self->dbh->{FetchHashKeyName} = 'NAME_lc';
 
     my $sth = $self->dbh->prepare(
-      "pragma table_info(" . $self->dbh->quote_identifier($table) . ")"
+        "pragma table_info(" . $self->dbh->quote_identifier($table) . ")"
     );
     $sth->execute;
     my $cols = $sth->fetchall_hashref('name');
@@ -81,12 +81,12 @@ sub _columns_info_for {
     # set it is_auto_increment. This isn't 100%, but it's better than the
     # alternatives.
     while (my ($col_name, $info) = each %$result) {
-      if ($cols{$col_name}{pk}) {
-        $num_pk++;
-        if (lc($cols{$col_name}{type}) eq 'integer') {
-          $pk_col = $col_name;
+        if ($cols{$col_name}{pk}) {
+            $num_pk++;
+            if (lc($cols{$col_name}{type}) eq 'integer') {
+                $pk_col = $col_name;
+            }
         }
-      }
     }
 
     while (my ($col, $info) = each %$result) {
@@ -94,7 +94,7 @@ sub _columns_info_for {
             ${ $info->{default_value} } = 'current_timestamp';
         }
         if ($num_pk == 1 and defined $pk_col and $pk_col eq $col) {
-          $info->{is_auto_increment} = 1;
+            $info->{is_auto_increment} = 1;
         }
     }
 
@@ -153,9 +153,9 @@ EOF
                 foreign \s+ key \s* \( \s* $local_cols \s* \) \s* references \s* (?:\S+|".+?(?<!")") \s*
                 (?:\( \s* $remote_cols \s* \) \s*)?
                 (?:(?:
-                  on \s+ (?:delete|update) \s+ (?:set \s+ null|set \s+ default|cascade|restrict|no \s+ action)
+                    on \s+ (?:delete|update) \s+ (?:set \s+ null|set \s+ default|cascade|restrict|no \s+ action)
                 |
-                  match \s* (?:\S+|".+?(?<!")")
+                    match \s* (?:\S+|".+?(?<!")")
                 ) \s*)*
                 ((?:not)? \s* deferrable)?
         /sxi;
@@ -226,11 +226,11 @@ sub _table_uniq_info {
         push @uniqs, [ $name => \@cols ];
     }
     $sth->finish;
-    return \@uniqs;
+    return [ sort { $a->[0] cmp $b->[0] } @uniqs ];
 }
 
 sub _tables_list {
-    my ($self, $opts) = @_;
+    my ($self) = @_;
 
     my $sth = $self->dbh->prepare("SELECT * FROM sqlite_master");
     $sth->execute;
@@ -248,7 +248,7 @@ sub _tables_list {
         );
     }
     $sth->finish;
-    return $self->_filter_tables(\@tables, $opts);
+    return $self->_filter_tables(\@tables);
 }
 
 sub _table_info_matches {
@@ -265,9 +265,9 @@ sub _table_info_matches {
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+See L<DBIx::Class::Schema::Loader/AUTHORS>.
 
 =head1 LICENSE
 
