@@ -5,15 +5,14 @@ use warnings;
 use base 'DBIx::Class::Schema::Loader::DBI';
 use mro 'c3';
 use Carp::Clan qw/^DBIx::Class/;
-use List::Util 'first';
-use List::MoreUtils 'any';
+use List::Util qw/any first/;
 use Try::Tiny;
 use Scalar::Util 'blessed';
 use DBIx::Class::Schema::Loader::Utils qw/sigwarn_silencer/;
 use namespace::clean;
 use DBIx::Class::Schema::Loader::Table ();
 
-our $VERSION = '0.07036_04';
+our $VERSION = '0.07048_01';
 
 =head1 NAME
 
@@ -66,12 +65,6 @@ sub _system_schemas {
     return ($self->next::method(@_), 'mysql');
 }
 
-sub _tables_list {
-    my ($self, $opts) = @_;
-
-    return $self->next::method($opts, undef, undef);
-}
-
 sub _table_fk_info {
     my ($self, $table) = @_;
 
@@ -112,7 +105,7 @@ sub _table_fk_info {
             local $self->{db_schema} = [ $f_schema ] if $f_schema;
 
             first {
-                   lc($_->name) eq lc($f_table)
+                lc($_->name) eq lc($f_table)
                 && ((not $f_schema) || lc($_->schema) eq lc($f_schema))
             } $self->_tables_list;
         };
@@ -204,7 +197,7 @@ sub _table_uniq_info {
 
     my @uniqs;
     my $keydata = $self->_mysql_table_get_keys($table);
-    foreach my $keyname (keys %$keydata) {
+    foreach my $keyname (sort keys %$keydata) {
         next if $keyname eq 'PRIMARY';
         push(@uniqs, [ $keyname => $keydata->{$keyname} ]);
     }
@@ -233,7 +226,7 @@ sub _columns_info_for {
         my ($precision, $scale, $column_type, $default) = eval { $self->dbh->selectrow_array(<<'EOF', {}, $table->name, lc($col)) };
 SELECT numeric_precision, numeric_scale, column_type, column_default
 FROM information_schema.columns
-WHERE table_name = ? AND lower(column_name) = ?
+WHERE table_schema = schema() AND table_name = ? AND lower(column_name) = ?
 EOF
         my $has_information_schema = not $@;
 
@@ -370,14 +363,26 @@ sub _column_comment {
     return $comment;
 }
 
+sub _view_definition {
+    my ($self, $view) = @_;
+
+    return scalar $self->schema->storage->dbh->selectrow_array(
+        q{SELECT view_definition
+            FROM information_schema.views
+           WHERE table_schema = schema()
+             AND table_name = ?
+        }, undef, $view->name,
+    );
+}
+
 =head1 SEE ALSO
 
 L<DBIx::Class::Schema::Loader>, L<DBIx::Class::Schema::Loader::Base>,
 L<DBIx::Class::Schema::Loader::DBI>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-See L<DBIx::Class::Schema::Loader/AUTHOR> and L<DBIx::Class::Schema::Loader/CONTRIBUTORS>.
+See L<DBIx::Class::Schema::Loader/AUTHORS>.
 
 =head1 LICENSE
 
